@@ -1,7 +1,8 @@
+<?php session_start() ?>
 <HTML>
-<HEAD><TITLE>Schedule <?php echo $_REQUEST['schedule'] ?></TITLE></HEAD>
+<HEAD><TITLE>Schedule <?php echo $_SESSION['schedule'] ?></TITLE></HEAD>
 <BODY>
-<H1>Schedule <?php echo $_REQUEST['schedule'] ?></H1>
+<H1>Schedule <?php echo $_SESSION['schedule'] ?></H1>
 
 <P>Adding movie <?php echo $_REQUEST['title'] ?> at <?php echo $_REQUEST['start_time'] ?>.</P>
 
@@ -15,7 +16,7 @@ if (!$database) {
 }
 
 
-if (! pg_insert($database, "content_schedule", $_POST) ) {
+if (! pg_insert($database, "content_schedule", array_merge($_POST, $_SESSION)) ) {
   echo "Error inserting! " . pg_last_error();
   exit;
 }
@@ -25,7 +26,7 @@ pg_query($database, "NOTIFY content_schedule;");
 ?>
 
 
-<P><A HREF="playback_schedule.php?schedule_name=<?php echo $_REQUEST['schedule'] ?>">Back to schedule <?php echo $_REQUEST['schedule']?></A>
+<P><A HREF="playback_schedule.php">Back to schedule <?php echo $_SESSION['schedule']?></A>
 
 </BODY>
 </HTML>
